summaryrefslogtreecommitdiff
path: root/lib/Target/X86/X86JITInfo.h
diff options
context:
space:
mode:
authorEvan Cheng <evan.cheng@apple.com>2008-11-05 01:50:32 +0000
committerEvan Cheng <evan.cheng@apple.com>2008-11-05 01:50:32 +0000
commitc96a8e7df1ffeebc5fb876f5eef380e8547ce14f (patch)
tree7830d261da19810d78b38ffcb0e88cf68d39af93 /lib/Target/X86/X86JITInfo.h
parentc9eaef0bf2d22f9f3ef3148560ae4159d357a76c (diff)
downloadllvm-c96a8e7df1ffeebc5fb876f5eef380e8547ce14f.tar.gz
llvm-c96a8e7df1ffeebc5fb876f5eef380e8547ce14f.tar.bz2
llvm-c96a8e7df1ffeebc5fb876f5eef380e8547ce14f.tar.xz
Rename isGVLazyPtr to isGVNonLazyPtr relocation. This represents Mac OS X
indirect gv reference. Please don't call it lazy. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@58746 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/X86/X86JITInfo.h')
-rw-r--r--lib/Target/X86/X86JITInfo.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/lib/Target/X86/X86JITInfo.h b/lib/Target/X86/X86JITInfo.h
index 6b8d197846..65a417dde8 100644
--- a/lib/Target/X86/X86JITInfo.h
+++ b/lib/Target/X86/X86JITInfo.h
@@ -37,10 +37,11 @@ namespace llvm {
///
virtual void replaceMachineCodeForFunction(void *Old, void *New);
- /// emitGlobalValueLazyPtr - Use the specified MachineCodeEmitter object to
- /// emit a lazy pointer which contains the address of the specified ptr.
- virtual void *emitGlobalValueLazyPtr(const GlobalValue* GV, void *ptr,
- MachineCodeEmitter &MCE);
+ /// emitGlobalValueNonLazyPtr - Use the specified MachineCodeEmitter object
+ /// to emit a Mac OS X non-lazy pointer which contains the address of the
+ /// specified ptr.
+ virtual void *emitGlobalValueNonLazyPtr(const GlobalValue* GV, void *ptr,
+ MachineCodeEmitter &MCE);
/// emitFunctionStub - Use the specified MachineCodeEmitter object to emit a
/// small native function that simply calls the function at the specified